@@ -7,4 +7,4 @@
  * License: 3-clause BSD, see https://opensource.org/licenses/BSD-3-Clause
  */
 
-pub(super) static EXIT_UNSUPPORTED_TAG_TYPE: i32 = 65;
+pub static EXIT_UNSUPPORTED_TAG_TYPE: i32 = 65;
